==> kubernetes-model-flowcontrol-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/PriorityLevelConfigurationReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PriorityLevelConfigurationReferenceBuilder extends PriorityLevelConfigurationReferenceFluentImpl<PriorityLevelConfigurationReferenceBuilder> implements VisitableBuilder<PriorityLevelConfigurationReference,PriorityLevelConfigurationReferenceBuilder>{
  public PriorityLevelConfigurationReferenceBuilder() {
    this(false);
  }
  public PriorityLevelConfigurationReferenceBuilder(Boolean validationEnabled) {
    this(new PriorityLevelConfigurationReference(), validationEnabled);
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PriorityLevelConfigurationReference(), validationEnabled);
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReferenceFluent<?> fluent,PriorityLevelConfigurationReference instance) {
    this(fluent, instance, false);
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReferenceFluent<?> fluent,PriorityLevelConfigurationReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReference instance) {
    this(instance,false);
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PriorityLevelConfigurationReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public PriorityLevelConfigurationReference build() {
    PriorityLevelConfigurationReference buildable = new PriorityLevelConfigurationReference(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-flowcontrol-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/PriorityLevelConfigurationReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PriorityLevelConfigurationReferenceBuilder extends PriorityLevelConfigurationReferenceFluent<PriorityLevelConfigurationReferenceBuilder> implements VisitableBuilder<PriorityLevelConfigurationReference,PriorityLevelConfigurationReferenceBuilder>{
  public PriorityLevelConfigurationReferenceBuilder() {
    this(false);
  }
  public PriorityLevelConfigurationReferenceBuilder(Boolean validationEnabled) {
    this(new PriorityLevelConfigurationReference(), validationEnabled);
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PriorityLevelConfigurationReference(), validationEnabled);
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReferenceFluent<?> fluent,PriorityLevelConfigurationReference instance) {
    this(fluent, instance, false);
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReferenceFluent<?> fluent,PriorityLevelConfigurationReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PriorityLevelConfigurationReference());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReference instance) {
    this(instance,false);
  }
  public PriorityLevelConfigurationReferenceBuilder(PriorityLevelConfigurationReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PriorityLevelConfigurationReference());

    if (instance != null) {
      this.withName(instance.getName());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PriorityLevelConfigurationReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public PriorityLevelConfigurationReference build() {
    PriorityLevelConfigurationReference buildable = new PriorityLevelConfigurationReference(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
